#
# spec file for package mpvpaper
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mpvpaper
Version:        1.6
Release:        1.1
Summary:        A video wallpaper program for wlroots based wayland compositors
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Other
URL:            https://github.com/GhostNaN/mpvpaper
Source:         https://github.com/GhostNaN/mpvpaper/archive/%{version}.tar.gz
BuildRequires:  meson
BuildRequires:  mpv-devel
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  wayland-protocols-devel
BuildRequires:  wlroots-devel
Requires:       mpv

%description
A video wallpaper program for wlroots based wayland compositors.

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
install -Dm644 %{name}.man "%{buildroot}%{_mandir}/man1/%{name}.1"

%files
%license LICENSE
%doc README.md
%{_bindir}/mpvpaper
%{_bindir}/mpvpaper-holder
%{_mandir}/man1/mpvpaper.1%{?ext_man}

%changelog
* Mon May 13 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.6:
  * Fix support for the Nvidia proprietary drivers
    This required 3 edits found here: eaaed11 408092d 9a03925
  * Change EGL errors into a more readable string
  * Improve memory safety
  * Reformat code and other various fixes
  * Add detection of swww to the list of conflicting wallpapers
* Tue Apr 23 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.5:
  * Allow selecting multiple outputs at once without using "*"
    like: "DP-2 HDMI-A-1 DP-1"
  * Allow using the mpv option "--playlist" to load media
  * Load mpv options with the mpv option "config=yes"
    instead of manually loading
  * Override user configs with options passed with "--mpv-options/-o"
  * Fix vo=libmpv not being set when empty for mpv 0.38
* Fri Nov  3 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.4:
  * New "--help-output/-d" option to show outputs without "mpvpaper -v a a"
  * Improve verbose and error messages
  * Move and fix up EGL and mpv inits
  * Small cleanups for "pausing" and "stopping" behavior
  * Fix int overflow for getopt_long() on ARM
* Mon Sep 26 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.3:
  * Ability to display to all outputs with "*" #26
  * Support for outputs with scaling
  * Replaced Wayland protocols xdg_output with wl_output v4
  * Updated GLAD library and Wayland protocols
  * Some code cleanup and various fixes
* Fri Feb 25 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.2.1:
  * Deprecated MPV_EVENT_PAUSE, MPV_EVENT_UNPAUSE, MPV_EVENT_IDLE
    replaced #19
  * mpv's "idle" option is now always off/no.
    Too many issues, this should help some that have been crashing
    lately
  * More various fixes outlined here: 50c0c8d
- Remove Fixed-mpv-events-cleanup-and-more.patch: upstreamed
* Thu Feb 24 2022 Fusion Future <qydwhotmail@gmail.com>
- Use patch from the upstream (https://github.com/GhostNaN/mpvpaper/commit/50c0c8def6d96bb2f992fad6c77b86fa85e1a596)
  * Fixed-mpv-events-cleanup-and-more.patch
- Drop old patch
  * observe-property-instead-of-MPV_EVENT-since-mpv-deprecated.patch
* Mon Feb 21 2022 Fusion Future <qydwhotmail@gmail.com>
- Fix build with removed deprecated APIs in mpv 2.x
  (gh#mpv-player/mpv#9541, gh#GhostNaN/mpvpaper#19)
  * observe-property-instead-of-MPV_EVENT-since-mpv-deprecated.patch
* Wed Nov 17 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.2:
  * New man page
  * New "--slideshow/-n" option
  * Improve usage text
  * Various fixes 2ebddae d8e5f23 275410e
* Thu Jul 29 2021 Paolo Perego <paolo.perego@suse.com>
- Added missing dependency: wayland-protocols-devel
* Sat Dec  5 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.1:
  * 2 new options "--auto-pause/-p" and "--auto-stop/-s"
  * 2 watch lists "pauselist" and "stoplist"
  * New program called "mpvpaper-holder" to facilitate "stopping" mpvpaper
  * User configs in "~/.config/mpv/" are now loaded
  * mpv terminal mode is enabled by default for better controls
    set "terminal=no" mpv option if you don't want that
  * Various minor improvements
  * See https://github.com/GhostNaN/mpvpaper/releases/tag/1.1
* Mon Nov 23 2020 Michael Vetter <mvetter@suse.com>
- Initial package of mpvpaper 1.0 for openSUSE
